@@ -1,3 +1,4 @@
+import asyncio
 from typing import Dict
 from urllib.parse import urlparse
 
@@ -11,3 +12,10 @@ class KafkaBackend(BroadcasterKafkaBackend):
 
     async def unsubscribe(self, channel: str) -> None:
         self._consumer.unsubscribe()
+
+    async def disconnect(self) -> None:
+        await self._producer.stop()
+        try:
+            await asyncio.wait_for(self._consumer.stop(), timeout=1)
+        except asyncio.TimeoutError:
+            await self._consumer._client.close()
